"use client";
import React, { useEffect, useState, useRef } from "react";
import { Stepper, Step, StepLabel } from "@/components/ui/steps";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { useTranslations } from "next-intl";
import toast, { Toaster } from "react-hot-toast";
import {
  postApiData,
  postWithToken,
  postApiFormDataToken,
  postApiFormDataTokenWithProgress,
} from "@/Helper/common";
import { CircularProgress } from "@/components/ui/progress";
import { FileUploader } from "react-drag-drop-files";
import Select from 'react-dropdown-select';

import { cn } from "@/lib/utils";
import { useMediaQuery } from "@/hooks/use-media-query";
import { getWithToken } from "@/Helper/common";
import { ifStatement } from "@babel/types";
import { useRouter } from "next/navigation";
import { useLanguage } from '../../../../../../context/LanguageContext';
import { Divider } from "@mantine/core";
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group";


const BasicWizard = () => {
  // otp form
  const { locale, changeLanguage, messages } = useLanguage();

  const fileTypes = ["JPG", "PNG", "GIF", 'jpg', 'jpeg', 'png'];
  const lang = useTranslations("Kyc_Update");
  const route = useRouter();
  const [location, setLocation] = useState();
  const [countdown, setCountdown] = useState(0);
  const [isCounting, setIsCounting] = useState(false);
  const [onlineVerifyBank, setOnlineVerifyBank] = useState('Pending');
  const [stateData, setStateData] = useState([]);
  const [cityData, setCityData] = useState([]);
  const [cityBusinessData, setCityBusinessData] = useState([]);
  const [selected, setSelected] = useState('Yes');
  const [registerAsARetailer, setRegisterAsARetailer] = useState(false);


  useEffect(() => {
    if ("geolocation" in navigator) {
      navigator.geolocation.getCurrentPosition(({ coords }) => {
        const { latitude, longitude } = coords;
        const formattedLatitude = parseFloat(latitude).toFixed(4);
        const formattedLongitude = parseFloat(longitude).toFixed(4);

        setLocation({
          latitude: formattedLatitude,
          longitude: formattedLongitude,
        });
        console.log({
          latitude: formattedLatitude,
          longitude: formattedLongitude,
        });
      });
    }
  }, []);

  useEffect(() => {
    let timer;
    if (isCounting && countdown > 0) {
      timer = setInterval(() => {
        setCountdown(prevCountdown => prevCountdown - 1);
      }, 1000);
    } else if (countdown === 0) {
      setIsCounting(false);
    }
    return () => clearInterval(timer);
  }, [isCounting, countdown]);



  const totalOtpField = 6;
  const otpArray = Array.from({ length: totalOtpField }, () => "");
  const [otp, setOtp] = useState(otpArray);
  const otpFields = Array.from({ length: totalOtpField }, (_, index) => index);
  const inputRefs = useRef([]);

  const handleChange = (e, index) => {
    const { value } = e.target;
    if (!isNaN(value) && value.length <= 1) {
      const newOtp = [...otp];
      newOtp[index] = value;
      setOtp(newOtp);
      if (value.length === 1 && index < totalOtpField - 1) {
        inputRefs.current[index + 1].focus();
      }
    }
  };
  const handleKeyDown = (index, event) => {
    if (event.key === "Backspace" && otp[index] === "" && index > 0) {
      setOtp((prevOtp) => {
        const newOtp = [...prevOtp];
        newOtp[index - 1] = "";
        return newOtp;
      });
      inputRefs.current[index - 1].focus();
    } else if (event.key === "ArrowLeft" && index > 0) {
      inputRefs.current[index - 1].focus();
    } else if (event.key === "ArrowRight" && index < numInputs - 1) {
      inputRefs.current[index + 1].focus();
    }
  };
  const isOtpComplete = otp.every((digit) => digit !== "");
  // end otp form

  const [activeStep, setActiveStep] = React.useState(0);
  const [resultData, setKycDetailsData] = useState([]);
  // first form
  const [fname, setFname] = useState("");
  const [mname, setMname] = useState("");
  const [lname, setLname] = useState("");
  const [email, setEmail] = useState("");
  const [date, setDate] = useState("");
  const [address, setAddress] = useState("");
  const [city, setCity] = useState("");
  const [state, setState] = useState("");
  const [pincode, setPincode] = useState("");

  // sencod form

  // Individual state variables for business-related fields
  const [businessType, setBusinessType] = useState("");
  const [businessName, setBusinessName] = useState("");
  const [businessMobile, setBusinessMobile] = useState("");
  const [businessAdd, setBusinessAdd] = useState("");
  const [businessCity, setBusinessCity] = useState("");
  const [businessState, setBusinessState] = useState("");
  const [businessPincode, setBusinessPincode] = useState("");

  const [bankName, setBankName] = useState("");
  const [branchName, setBranchName] = useState("");
  const [accountHolderName, setAccountHolderName] = useState("");
  const [accountNumber, setAccountNumber] = useState("");
  const [ifscCode, setIfscCode] = useState("");
  const [bankVerifyLoading, setBankVerifyLoading] = useState(false);
  const [bankVerify, setBankVerify] = useState(false);
  const [bankVerifyShowButton, setBankVerifyShowButton] = useState(true);

  const [aadharNum, setAadharNum] = useState("");
  const [aadharName, setAadharName] = useState("");
  const [panNumber, setPanNumber] = useState("");

  const [aadharCardValidation, setAadharCardValidation] = useState(false);
  const [hideVerifyAadharPanButton, setHideVerifyAadharPanButton] =
    useState(false);

  // for aadhar otp verify
  const [request_id, setRequestId] = useState("");

  const [showOTP, setShowOTP] = useState(false);
  const [loading, setLoading] = useState(false);

  const [AadharVerifyLoading, setAadharVerifyLoading] = useState(false);
  const [AadharOtpVerifyLoading, setAadharOtpVerifyLoading] = useState(false);
  const [panVerifyLoading, setPanVerifyLoading] = useState(false);
  const [verifyBankSkip, setVerifyBankSkip] = useState(true);

  const [gst, setGstQuestion] = useState("");
  const [online_verify_aadhar, setOnlineVerifyAadhar] = useState("No");
  const [online_verify_pan, setOnlineVerifyPan] = useState("No");
  const [ekyc, setEkyc] = useState("No");
  const [showGSTInput, setShowGSTInput] = useState(false);
  const [gstNumber, setGSTNumber] = useState("");
  const [designationType, setDesignationType] = useState("");
  const [aadharCardData, setAadharCardData] = useState('');
  const [panCardData, setPanCardData] = useState("");
  const [bankData, setBankData] = useState("");
  const [aeps_bank_id, setBankId] = useState('');
  const [user_id, setUserId] = useState(0);
  const [bankList, setBankList] = useState([]);

  // upload image work single-single

  const [loadingImageSubmit, setLoadingImageSubmit] = useState(false);
  const [uploadImageType, setUploadImageType] = useState('');
  const [uploadProgress, setUploadProgress] = useState(0);
  const [uploadAFrontImageId, setUploadAFrontImageId] = useState(0);
  const [uploadABackImageId, setUploadABackImageId] = useState(0);
  const [uploadPanImageId, setUploadPanImageId] = useState(0);
  const [uploadPhotoImageId, setUploadPhotoImageId] = useState(0);
  const [uploadBankImageId, setUploadBankImageId] = useState(0);
  const [uploadPVImageId, setUploadPVImageId] = useState(0);

  useEffect(() => {
    fetchKycData();
    fetchAepsBankData();
  }, []);

  var apiCall = true;

  const fetchKycData = async () => {
    try {

      if (apiCall) {

        apiCall = false;

        const apiResData = await getWithToken("get-kyc-details");
        // console.log(apiResData);
        if (apiResData.error === false) {
          setKycDetailsData(apiResData.data);
          if (apiResData.data) {
            setFname(apiResData?.data.first_name);
            setLname(apiResData?.data.last_name);
            setEmail(apiResData?.data.email);
            setDesignationType(apiResData?.userData.designation_id);
            setUserId(apiResData?.userData?.id);
          }
        }

        const getState = await getWithToken("web/getStateData");
        // console.log(apiResData);
        if (getState.error === false) {
          setStateData(getState.result);

        }
      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };


  const fetchAepsBankData = async () => {
    try {

      const apiResData = await getWithToken(`beneficiary/get-aeps-bank-data`);
      // console.log(apiResData);
      if (apiResData.error === false) {

        setBankList(apiResData?.result);
      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };

  // validation form 1
  const [errors, setErrors] = useState({
    fname: "",
    lname: "",
    email: "",
    date: "",
    address: "",
    city: "",
    state: "",
    pincode: "",
    businessName: "",
    businessMobile: "",
    businessAdd: "",
    businessCity: "",
    businessState: "",
    businessPincode: "",
    bankName: "",
    branchName: "",
    bankCity: "",
    accountHolderName: "",
    accountNumber: "",
    ifscCode: "",
    aadharNum: "",
    aadharName: "",
    adharCardFrontImage: "",
    adharCardBackImage: "",
    panImage: "",
    selfImage: "",
    bankImage: "",
  });

  const [businessFormData, setBusinessFormData] = useState({
    businessType: "",
    businessName: "",
    businessMobile: "",
    businessAdd: "",
    businessCity: "",
    businessState: "",
    businessPincode: "",
  });

  // form 2

  const validateBasic = () => {
    let isValid = true;
    const newErrors = { ...errors };

    if (!designationType) {
      newErrors.designationType = "Registration type is required *";
      isValid = false;
    } else {
      newErrors.designationType = "";
    }

    if (!fname.trim()) {
      newErrors.fname = lang("fname");
      isValid = false;
    } else {
      newErrors.fname = "";
    }

    if (!email.trim()) {
      newErrors.email = lang("email");
      isValid = false;
    } else if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email.trim())) {
      // Check if email is in valid format
      newErrors.email = lang("validemail");
      isValid = false;
    } else {
      newErrors.email = "";
    }

    if (!date.trim()) {
      newErrors.date = lang("date");
      isValid = false;
    } else {
      const dob = new Date(date);
      const today = new Date();

      if (isNaN(dob.getTime())) {
        newErrors.date = lang("invalid_date"); // Localization for "Invalid date"
        isValid = false;
      } else {
        // Calculate age
        var age = today.getFullYear() - dob.getFullYear();
        const monthDiff = today.getMonth() - dob.getMonth();
        const dayDiff = today.getDate() - dob.getDate();

        if (monthDiff < 0 || (monthDiff === 0 && dayDiff < 0)) {
          age--;
        }

        if (age < 18) {
          newErrors.date = lang("min_age");
          isValid = false;
        } else {
          newErrors.date = "";
        }
      }
    }

    if (!address.trim()) {
      newErrors.address = lang("address");
      isValid = false;
    } else {
      newErrors.address = "";
    }

    if (!city.trim()) {
      newErrors.city = lang("city");
      isValid = false;
    } else {
      newErrors.city = "";
    }

    if (!state.trim()) {
      newErrors.state = lang("state");
      isValid = false;
    } else {
      newErrors.state = "";
    }

    if (!pincode.trim()) {
      newErrors.pincode = lang("pincode");
      isValid = false;
    } else if (!/^\d+$/.test(pincode.trim())) {
      // Check if pincode is numeric
      newErrors.pincode = lang("pinvalid");
      isValid = false;
    } else {
      newErrors.pincode = "";
    }

    setErrors(newErrors);
    return isValid;
  };

  //

  const validateBusiness = () => {
    let isValid = true;
    const newErrors = { ...errors };

    if (!businessName.trim()) {
      newErrors.businessName = lang("businessName");
      isValid = false;
    } else {
      newErrors.businessName = "";
    }
    if (!businessMobile.trim()) {
      newErrors.businessMobile = lang("businessMobile");
      isValid = false;
    } else {
      newErrors.businessMobile = "";
    }

    if (!businessAdd.trim()) {
      newErrors.businessAdd = lang("businessAdd");
      isValid = false;
    } else {
      newErrors.businessAdd = "";
    }

    if (!businessCity.trim()) {
      newErrors.businessCity = lang("businessCity");
      isValid = false;
    } else {
      newErrors.businessCity = "";
    }

    if (!businessState.trim()) {
      newErrors.businessState = lang("businessState");
      isValid = false;
    } else {
      newErrors.businessState = "";
    }

    if (!businessPincode.trim()) {
      newErrors.businessPincode = lang("businessPincode");
      isValid = false;
    } else if (!/^\d+$/.test(businessPincode.trim())) {
      newErrors.pincode = "Pincode must be numeric *";
      isValid = false;
    } else {
      newErrors.businessPincode = "";
    }

    if (showGSTInput) {
      const gstNumberPattern =
        /^[0-9]{2}[A-Z]{5}[0-9]{4}[A-Z]{1}[1-9A-Z]{1}Z[0-9A-Z]{1}$/;

      if (!gstNumber.trim()) {
        newErrors.gstNumber = "GST Number is required *";
        isValid = false;
      } else if (!gstNumberPattern.test(gstNumber.trim())) {
        newErrors.gstNumber = "Invalid GST Number format *";
        isValid = false;
      } else {
        newErrors.gstNumber = "";
      }
    }

    setErrors(newErrors);
    return isValid;
  };

  const validateBank = () => {
    let isValid = true;
    const newErrors = { ...errors };

    if (!bankName.trim()) {
      newErrors.bankName = lang("bankName");
      isValid = false;
    } else if (!/^[a-zA-Z\s]+$/.test(bankName.trim())) {
      isValid = false;
    } else {
      newErrors.bankName = "";
    }

    if (!branchName.trim()) {
      newErrors.branchName = lang("branchName");
      isValid = false;
    } else if (!/^[a-zA-Z\s]+$/.test(branchName.trim())) {
      isValid = false;
    } else {
      newErrors.branchName = "";
    }

    if (!accountHolderName.trim()) {
      newErrors.accountHolderName = lang("accountHolderName");
      isValid = false;
    } else if (!/^[a-zA-Z\s]+$/.test(accountHolderName.trim())) {
      isValid = false;
    } else {
      newErrors.accountHolderName = "";
    }

    if (!accountNumber.trim()) {
      newErrors.accountNumber = lang("accountNumber");
      isValid = false;
    } else if (!/^\d+$/.test(accountNumber.trim())) {
      isValid = false;
    } else {
      newErrors.accountNumber = "";
    }

    const ifscCodePattern = /^[A-Z]{4}0[A-Z0-9]{6}$/;

    if (!ifscCode.trim()) {
      newErrors.ifscCode = lang("ifscCode");
      isValid = false;
    } else if (!ifscCodePattern.test(ifscCode.trim())) {
      newErrors.ifscCode = "Invalid IFSC Code format *";
      isValid = false;
    } else {
      newErrors.ifscCode = "";
    }
    setErrors(newErrors);
    return isValid;
  };

  const validateKyc = () => {
    let isValid = true;
    const newErrors = { ...errors };

    // if (!aadharName.trim()) {
    //   newErrors.aadharName = lang("aadharName");
    //   isValid = false;
    // } else {
    //   newErrors.aadharName = "";
    // }

    if (!aadharNum.trim()) {
      newErrors.aadharNum = lang("aadharNum");
      isValid = false;
    } else {
      newErrors.aadharNum = "";
    }

    setErrors(newErrors);
    return isValid;
  };

  const validateKycDocument = () => {
    let isValid = true;
    const newErrors = { ...errors };

    if (!adharCardFrontImage) {
      newErrors.adharCardFrontImage = 'Aadhar Card front image is required';
      isValid = false;
    } else {
      newErrors.adharCardFrontImage = "";
    }

    if (!adharCardBackImage) {
      newErrors.adharCardBackImage = 'Aadhar Card back image is required';
      isValid = false;
    } else {
      newErrors.adharCardBackImage = "";
    }

    if (!panImage) {
      newErrors.panImage = 'Pan Card image is required';
      isValid = false;
    } else {
      newErrors.panImage = "";
    }

    if (!selfImage) {
      newErrors.selfImage = 'Photo with shop image is required';
      isValid = false;
    } else {
      newErrors.selfImage = "";
    }

    if (!bankImage) {
      newErrors.bankImage = 'Bank Cheque Photo is required';
      isValid = false;
    } else {
      newErrors.bankImage = "";
    }

    setErrors(newErrors);
    return isValid;
  };

  const steps = [
    lang("Basic_Details"),
    lang("Business_Details"),
    lang("Bank_Details"),
    lang("KYC_Documents")
  ];

  const isStepOptional = (step) => {
    return step === 1;
  };

  const nameUpperCase = () => {
    const formattedFname = fname.toUpperCase();
    const formattedMname = mname ? mname.toUpperCase() : '';
    const formattedLname = lname.toUpperCase();

    var full_user_name = formattedFname;

    if (formattedMname) {
      full_user_name += ' ' + formattedMname;
    }

    if (formattedLname) {
      full_user_name += ' ' + formattedLname;
    }
    return full_user_name;
  }

  const handleNext = () => {
    if (activeStep === 0) {
      if (validateBasic()) {
        setBankVerifyShowButton(true);
        setActiveStep((prevActiveStep) => prevActiveStep + 1);
      }
    } else if (activeStep === 1) {
      if (validateBusiness()) {

        setBankVerifyShowButton(false);
        setBankVerify(false);
        setActiveStep((prevActiveStep) => prevActiveStep + 1);
      }
    } else if (activeStep === 2) {
      if (validateBank()) {
        setBankVerifyShowButton(true);
        setActiveStep((prevActiveStep) => prevActiveStep + 1);
      }
    } else if (activeStep === 3) {

      if (validateKyc()) {
        setBankVerifyShowButton(true);
        setActiveStep((prevActiveStep) => prevActiveStep + 1);
      }
    }

    // if(validateForm()){
    // setActiveStep((prevActiveStep) => prevActiveStep + 1);

    // }
  };

  const handleBack = () => {
    setActiveStep((prevActiveStep) => prevActiveStep - 1);
    setBankVerifyShowButton(true);
  };

  const handleReset = () => {
    setActiveStep(0);
  };

  const isTablet = useMediaQuery("(max-width: 1024px)");

  const handleSelectChange = (event) => {
    const selectedValue = event.target.value;
    setGstQuestion(selectedValue);
    setShowGSTInput(selectedValue === "Yes");
    setGSTNumber("");
  };

  const handleSelectBusinessTypeChange = (event) => {
    const selectedValue = event.target.value;
    setBusinessType(selectedValue);
  };

  const handleSelectRegistrationTypeChange = (event) => {
    const selectedValue = event.target.value;
    setDesignationType(selectedValue);
  };

  const [showOTPForm, setShowOTPForm] = useState(false);
  const [finalSubmitLoading, setFinalSubmitLoading] = useState(false);
  const [showManualMessage, setShowManualMessage] = useState('');
  const [showUploadDocumentForm, setShowUploadDocumentForm] = useState(false);
  // const [OTP, setOTP] = useState('');

  // otp verify
  const handleVerify = async () => {
    toast.dismiss();
    const apiData = JSON.stringify({
      aadhar_number: aadharNum,
      aadhar_name: 'Aadhar',
    });

    try {
      setAadharVerifyLoading(true);

      const data = await postWithToken("aadhar-card-number-verify", apiData);
      var messageshow = data.message;
      if (locale === "hi") {
        messageshow = messages.ErrorMessage[data.response_code];
      }
      if (data.error == false) {
        toast.success(messageshow, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

        setShowOTPForm(true);
        setRequestId(data.request_id);
        setAadharVerifyLoading(false);
        setCountdown(60); // Set the countdown duration (in seconds)
        setIsCounting(true);
      } else {
        if (data.manual) {
          setShowOTPForm(false);
          setShowManualMessage(data.message);
          setShowUploadDocumentForm(true);
          setHideVerifyAadharPanButton(true);
        }

        toast.error(messageshow, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setAadharVerifyLoading(false);
      }
    } catch (errorData) {
      toast.error(messageshow, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setAadharVerifyLoading(false);
    }
  };

  // send otp
  const AadharOtoVerify = async () => {
    const enteredOtp = otp.join("");

    const apiData = JSON.stringify({ request_id: request_id, otp: enteredOtp });

    try {
      setAadharOtpVerifyLoading(true);

      const data = await postWithToken(
        "aadhar-card-number-otp-verify",
        apiData
      );

      if (data.error == false) {
        toast.success(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

        setAadharCardData(data?.result);

        setOnlineVerifyAadhar("Yes");

        var formattedUserFullName = data.result?.user_full_name?.toUpperCase() || '';
        var upper_name = nameUpperCase();

        if (formattedUserFullName === upper_name) {
          setAadharCardValidation(true);
          setShowOTPForm(false);
          setAadharOtpVerifyLoading(false);

        } else {

          setShowManualMessage('Aadhar card details not match');
          setShowUploadDocumentForm(true);
          setEkyc("No");
          setShowOTPForm(false);
          setHideVerifyAadharPanButton(true);
        }


      } else {

        if (data.manual) {
          setShowManualMessage(data.message);
          setShowUploadDocumentForm(true);
          setShowOTPForm(false);
          setHideVerifyAadharPanButton(true);
        }

        toast.error(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setAadharOtpVerifyLoading(false);
      }
    } catch (errorData) {
      toast.error(errorData.message, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setAadharOtpVerifyLoading(false);
    }
  };

  // pan number verify
  const panNumberVerify = async () => {

    toast.dismiss();
    const apiData = JSON.stringify({ pan_number: panNumber });

    try {

      setPanVerifyLoading(true);

      const data = await postWithToken("pan-card-number-verify", apiData);

      var messageshow = data.message;
      if (locale === "hi") {
        messageshow = messages.ErrorMessage[data.response_code];
      }

      if (data.error == false) {

        toast.success(messageshow, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setPanCardData(data?.result);

        var formattedUserFullName = data.result?.user_full_name?.toUpperCase() || '';
        var upper_name = nameUpperCase();

        if (formattedUserFullName === upper_name) {
          setPanVerifyLoading(false);
          setOnlineVerifyPan("Yes");
          setEkyc("Yes");

        } else {

          setShowManualMessage('Pan card details not match');
          setShowUploadDocumentForm(true);
          setEkyc("No");
        }


      } else {

        if (data.manual) {
          setShowManualMessage(data.message);
          setShowUploadDocumentForm(true);
        }

        toast.error(messageshow, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setPanVerifyLoading(false);
      }
    } catch (errorData) {
      toast.error(messageshow, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setAadharVerifyLoading(false);
    }
  };

  // file state
  const [adharCardFrontImage, setAadharCardFrontImage] = useState("");
  const [adharCardBackImage, setAadharCardBackImage] = useState("");
  const [panImage, setPanImage] = useState("");
  const [selfImage, setSelfImage] = useState("");
  const [bankImage, setBankImage] = useState("");
  const [policeVerificationDocument, setPoliceVerificationDocument] = useState("");
  const [policeVerificationDocumentSkip, setPoliceVerificationDocumentSkip] = useState(true);
  const [progressKycSubmit, setProgressKycSubmit] = useState(0);


  const handleAadharCardFrontImageChange = (e) => {
    setAadharCardFrontImage(e);
  };

  const handleAadharCardBackImageChange = (e) => {
    setAadharCardBackImage(e);
  };

  const handlePanImageChange = (e) => {
    setPanImage(e);
  };

  const handleSelfImageChange = (e) => {
    setSelfImage(e);
  };

  const handleBankImageChange = (e) => {
    setBankImage(e);
  };

  const handlePoliceVerificationDocumentChange = (e) => {
    setPoliceVerificationDocument(e);
  };

  const handleChangePincode = (e) => {
    const { value } = e.target;
    if (/^\d*$/.test(value)) {
      setPincode(value);
    }
  };
  const handleChangeBusinessPincode = (e) => {
    const { value } = e.target;
    if (/^\d*$/.test(value)) {
      setBusinessPincode(value);
    }
  };

  const handleChangeBusinessMobile = (e) => {
    const { value } = e.target;
    if (/^\d*$/.test(value)) {
      setBusinessMobile(value.split(" ").join(""));
    }
  };


  const handleKycSubmit = async () => {

    setProgressKycSubmit(0);
    const onProgressKycSubmit = (progress) => {
      setProgressKycSubmit(progress); // Update progress in state
    };

    if (ekyc == 'No') {

      if (validateKycDocument()) {

        // return false;

      }

    }

    setFinalSubmitLoading(true);
    const apiData = new FormData();

    var formattedFname = fname.toUpperCase();
    var formattedMname = mname ? mname.toUpperCase() : '';

    var full_user_name = formattedFname;

    if (formattedMname) {
      full_user_name += ' ' + formattedMname;
    }

    apiData.append("first_name", full_user_name);
    apiData.append("last_name", lname);
    apiData.append("business_name", businessName);
    apiData.append("date_of_birth", date);
    apiData.append("permanent_address", address);
    apiData.append("city", city);
    apiData.append("state", state);
    apiData.append("pin_code", pincode);
    apiData.append("business_type", businessType);
    apiData.append("business_mobile", businessMobile);
    apiData.append("gst", gst);
    apiData.append("gst_number", gstNumber);
    apiData.append("business_pan", "");
    apiData.append("business_address", businessAdd);
    apiData.append("business_city", businessCity);
    apiData.append("business_state", businessState);
    apiData.append("business_pincode", businessPincode);
    apiData.append("passport_size_photo", selfImage);
    apiData.append("online_verify_aadhar", online_verify_aadhar);
    apiData.append("online_verify_pan", online_verify_pan);
    apiData.append("ekyc", ekyc);
    apiData.append("aadhar_number", aadharNum);
    apiData.append("aadhar_front_image", adharCardFrontImage);
    apiData.append("aadhar_back_image", adharCardBackImage);
    apiData.append("pancard_number", panNumber?.toUpperCase());
    apiData.append("pancard_image", panImage);
    apiData.append("bank_cheque_image", bankImage);
    apiData.append("policeVerificationDocument", policeVerificationDocument);
    apiData.append("bank_name", bankName);
    apiData.append("branch_name", branchName);
    apiData.append("account_holder_name", accountHolderName);
    apiData.append("account_number", accountNumber);
    apiData.append("ifsc_code", ifscCode);
    apiData.append("designation_id", designationType);
    apiData.append("aadhar_card_data", JSON.stringify(aadharCardData));
    apiData.append("pan_card_data", JSON.stringify(panCardData));
    apiData.append("bank_data", JSON.stringify(bankData));
    apiData.append("online_verify_bank", onlineVerifyBank);
    apiData.append("aeps_bank_id", aeps_bank_id);
    apiData.append("register_retailer", registerAsARetailer);
    apiData.append("latitude", location.latitude);
    apiData.append("longitude", location.longitude);
    apiData.append("uploadAFrontImageId", uploadAFrontImageId);
    apiData.append("uploadABackImageId", uploadABackImageId);
    apiData.append("uploadPanImageId", uploadPanImageId);
    apiData.append("uploadPhotoImageId", uploadPhotoImageId);
    apiData.append("uploadBankImageId", uploadBankImageId);
    apiData.append("uploadPVImageId", uploadPVImageId);

    try {
      toast.dismiss();
      const apiRes = await postApiFormDataTokenWithProgress(`admin-kyc-details`, apiData, onProgressKycSubmit);

      // console.log(apiRes);
      if (apiRes.error) {
        toast.error(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });
        setProgressKycSubmit(0);
      } else {
        toast.success(apiRes.message, {
          position: "bottom-center",
          style: {
            borderRadius: "10px",
            background: "#333",
            color: "#fff",
          },
        });

        route.push("/admin/set-mpin");
      }
    } catch (error) {
      console.error("Error uploading image:", error);
    } finally {
      setFinalSubmitLoading(false);
    }


  };

  // bank verify
  const verifyBankAccount = async () => {

    toast.dismiss();

    const apiData = JSON.stringify({
      user_id: user_id,
      account_number: accountNumber,
      ifsc_code: ifscCode,
      latitude: location.latitude,
      longitude: location.longitude,
    });

    try {

      setBankVerifyLoading(true);

      const data = await postWithToken("bank/verify-bank-account", apiData);
      // var messageshow = data.message;
      // if (locale === "hi") {
      //   messageshow = messages.ErrorMessage[data.response_code];
      // }
      if (data.error == false) {

        toast.success(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

        setAccountHolderName(data.result?.payee?.name);

        if (data.result?.payee?.name === accountHolderName) {
          setAccountHolderName(data.result?.payee?.name);
          setBankVerify(true);
          setEkyc("No");
          setShowManualMessage('Bank Account Not Match');
          setShowUploadDocumentForm(true);
        }

        setOnlineVerifyBank('Approved');

        setBankData(data.result);

        setIfscCode(data.result?.payee?.ifsc);

        setBankVerifyShowButton(true);

        setBankVerifyLoading(false);

      } else {

        toast.error(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setBankVerifyLoading(false);
      }
    } catch (errorData) {
      toast.error(data.message, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setBankVerifyLoading(false);
    }
  };

  const handleResend = () => {
    handleVerify();
  };

  const fetchCityData = async (id) => {
    try {

      const getState = await getWithToken("web/getCityData?stateId=" + id);
      // console.log(apiResData);
      if (getState.error === false) {
        setCityData(getState.result);

      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };

  const selectStateName = (value) => {

    setState(value[0]?.label);
    fetchCityData(value[0]?.value);

  };

  const selectCityName = (value) => {

    setCity(value[0]?.label);

  };


  const fetchCityBusinessData = async (id) => {
    try {

      const getState = await getWithToken("web/getCityData?stateId=" + id);
      // console.log(apiResData);
      if (getState.error === false) {
        setCityBusinessData(getState.result);

      }

    } catch (error) {
      console.error("Error fetching slider:", error);
      setLoading(false);
    }
  };

  const selectStateBusinessName = (value) => {

    setBusinessState(value[0]?.label);
    fetchCityBusinessData(value[0]?.value);

  };

  const selectCityBusinessName = (value) => {

    setBusinessCity(value[0]?.label);

  };

  const selectBankName = (value) => {

    setBankId(value[0]?.value);
    setBankName(value[0]?.label);

  };

  const verifyBankAccountSkip = () => {

    setVerifyBankSkip(false);

  };

  const [aadharVerifyDataSkip, setAadharVerifyDataSkip] = useState(false);
  const [panVerifyDataSkip, setPanVerifyDataSkip] = useState(false);

  const verifyAadharNumberSkip = () => {

    setShowUploadDocumentForm(true);
    setAadharVerifyDataSkip(true);

  };


  const verifyPanNumberSkip = () => {

    setShowUploadDocumentForm(true);
    setPanVerifyDataSkip(true);

  };

  const RegisterAsARetailerConfirm = (value) => {
    if (value === 'true') {
      const isConfirmed = window.confirm(
        "Are you sure you want to register as Retailer on Your Profile?"
      );

      if (isConfirmed) {
        setRegisterAsARetailer(true); // Set to true if confirmed
      } else {
        setRegisterAsARetailer(false); // Revert to false if not confirmed
      }
    } else {
      setRegisterAsARetailer(false); // Directly set to false for "No"
    }
  };

  const uploadImage = async (imageType) => {

    setUploadImageType(imageType);
    setUploadProgress(0);
    const onProgress = (progress) => {
      setUploadProgress(progress); // Update progress in state
    };

    setLoadingImageSubmit(true);

    toast.dismiss();

    try {

      const apiData = new FormData();

      apiData.append("image_type", imageType);
      if (imageType == 'aadhar_front') {
        apiData.append("image", adharCardFrontImage);
      } else if (imageType == 'aadhar_back') {
        apiData.append("image", adharCardBackImage);
      } else if (imageType == 'pancard_image') {
        apiData.append("image", panImage);
      } else if (imageType == 'photo_with_shop') {
        apiData.append("image", selfImage);
      } else if (imageType == 'bank_image') {
        apiData.append("image", bankImage);
      } else if (imageType == 'police_verification_image') {
        apiData.append("image", policeVerificationDocument);
      }

      const apiRes = await postApiFormDataTokenWithProgress("upload-image-single", apiData, onProgress);

      if (apiRes && apiRes.error == false) {

        if (imageType == 'aadhar_front') {
          setUploadAFrontImageId(apiRes.id);
        } else if (imageType == 'aadhar_back') {
          setUploadABackImageId(apiRes.id);
        } else if (imageType == 'pancard_image') {
          setUploadPanImageId(apiRes.id);
        } else if (imageType == 'photo_with_shop') {
          setUploadPhotoImageId(apiRes.id);
        } else if (imageType == 'bank_image') {
          setUploadBankImageId(apiRes.id);
        } else if (imageType == 'police_verification_image') {
          setUploadPVImageId(apiRes.id);
        }

        setUploadProgress(0);

        toast.success(apiRes.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

        setLoadingImageSubmit(false);
      } else {
        toast.error(apiRes.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setLoadingImageSubmit(false);
      }
    } catch (errorData) {
      toast.error(errorData.message, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setLoadingImageSubmit(false);
    }
  }

  const uploadRemoveImage = async (imageType) => {

    setUploadProgress(0);

    toast.dismiss();

    try {

      if (imageType == 'aadhar_front') {
        setUploadAFrontImageId(0);
        setAadharCardFrontImage('');
      } else if (imageType == 'aadhar_back') {
        setUploadABackImageId(0);
        setAadharCardBackImage('');
      } else if (imageType == 'pancard_image') {
        setPanImage('');
        setUploadPanImageId(0);
      } else if (imageType == 'photo_with_shop') {
        setUploadPhotoImageId(0);
        setSelfImage('');
      } else if (imageType == 'bank_image') {
        setUploadBankImageId(0);
        setBankImage('');
      } else if (imageType == 'police_verification_image') {
        setUploadPVImageId(0);
        setPoliceVerificationDocument('');
      }

    } catch (errorData) {
      toast.error(errorData.message, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });

    }
  }

  return (
    <div className="mt-4">
      <Stepper current={activeStep} direction={isTablet && "vertical"}>
        {steps.map((label, index) => {
          const stepProps = {};
          const labelProps = {};
          if (isStepOptional(index)) {
            labelProps.optional = (
              <StepLabel variant="caption">{lang("Optional")}</StepLabel>
            );
          }
          // if (isStepSkipped(index)) {
          //   stepProps.completed = false;
          // }
          return (
            <Step key={label} {...stepProps}>
              <StepLabel {...labelProps}>{label}</StepLabel>
            </Step>
          );
        })}
      </Stepper>

      {activeStep === steps.length ? (
        <React.Fragment>
          <div className="mt-2 mb-2 font-semibold text-center">
            {lang("All steps completed - you are finished")}
          </div>
          <div className="flex pt-2">
            <div className=" flex-1" />
            <Button
              size="xs"
              variant="outline"
              color="destructive"
              className="cursor-pointer"
              onClick={handleReset}
            >
              {lang("Reset")}
            </Button>
          </div>
        </React.Fragment>
      ) : (
        <React.Fragment>
          <form>
            <div className="grid grid-cols-12 gap-4">
              {activeStep === 0 && (
                <>
                  <div className="col-span-12 mb-4 mt-6">
                    <h4 className="text-sm font-medium text-default-600">
                      {lang("Enter_Your_Basic_Details")}
                    </h4>
                    {/* <p className="text-xs text-default-600 mt-1">
                      Fill in the box with correct data
                      form input 

                    </p> */}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Select Registration Type">
                      {" "}
                      {lang("Select_Registration_Type")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <select
                      disabled
                      onChange={handleSelectRegistrationTypeChange}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"
                    >
                      <option value="">  {lang("Select_Registration_Type")}</option>
                      <option
                        value="2"
                        selected={designationType == "2" ? true : false}
                      >
                        Custom Software
                      </option>
                      <option
                        value="3"
                        selected={designationType == "3" ? true : false}
                      >
                        {lang("Master_Distributor")}
                      </option>
                      <option
                        value="4"
                        selected={designationType == "4" ? true : false}
                      >
                        {lang("Distributor")}
                      </option>
                      <option
                        value="5"
                        selected={designationType == "5" ? true : false}
                      >
                        {lang("Retailer")}
                      </option>
                    </select>

                    {errors.designationType && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.designationType}
                      </span>
                    )}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="First Name">
                      {" "}
                      {lang("First_Name")}{" "}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      type="text"
                      value={fname}
                      // onChange={(e) => setFname(e.target.value)}
                      placeholder={lang("First_Name")}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[a-zA-Z_]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setFname(value); // Update state only if the value is valid
                        }
                      }}
                    />
                    {errors.fname && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.fname}
                      </span>
                    )}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Middle Name">
                      {" "}
                      {lang("Middle_Name")}{" "}
                    </Label>
                    <Input
                      type="text"
                      value={mname}
                      // onChange={(e) => setMname(e.target.value)}
                      placeholder={lang("Middle_Name")}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[a-zA-Z_]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setMname(value); // Update state only if the value is valid
                        }
                      }}
                    />

                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Last Name">
                      {lang("Last_Name")}

                    </Label>
                    <Input
                      type="text"
                      value={lname}
                      // onChange={(e) => setLname(e.target.value)}
                      placeholder={lang("Last_Name")}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[a-zA-Z_]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setLname(value); // Update state only if the value is valid
                        }
                      }}
                    />

                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Email Address">
                      {lang("Email_Address")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={email}
                      onChange={(e) => setEmail(e.target.value)}
                      type="email"
                      placeholder={lang("Email_Address")}
                    />
                    {errors.email && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.email}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Date of Birth">
                      {lang("Date_of_Birth")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={date}
                      onChange={(e) => setDate(e.target.value)}
                      type="date"
                      placeholder={lang("Date_of_Birth")}
                    />
                    {errors.date && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.date}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Permanent Address">
                      {lang("Permanent_Address")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={address}
                      onChange={(e) => setAddress(e.target.value)}
                      type="text"
                      placeholder={lang("Permanent_Address")}
                    />
                    {errors.address && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.address}
                      </span>
                    )}
                  </div>


                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Enter State">
                      {lang("State")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    {
                      stateData && stateData.length > 0 ?

                        <Select
                          options={stateData}
                          onChange={(values) => selectStateName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />

                        :

                        <Select
                          onChange={(values) => selectStateName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />
                    }

                    {errors.state && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.state}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Enter City">
                      {lang("City")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    {
                      cityData && cityData.length > 0 ?

                        <Select
                          options={cityData}
                          onChange={(values) => selectCityName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />

                        :

                        <Select
                          onChange={(values) => selectCityName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />
                    }

                    {errors.city && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.city}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Pin Code">
                      {lang("Pin_Code")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={pincode}
                      onChange={handleChangePincode}
                      type="text"
                      placeholder={lang("Pin_Code")}
                      maxLength={6}
                      minLength={6}
                    />
                    {errors.pincode && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.pincode}
                      </span>
                    )}
                  </div>

                  {
                    designationType == "3" || designationType == "4" ?

                      <>
                        <div className="col-span-12 lg:col-span-12 mt-5">
                          <Divider />
                        </div>

                        <div className="col-span-12 lg:col-span-12 mt-2">
                          <Label htmlFor="Select Registration Type" style={{ color: "red" }}>
                            You want to work as Retailer
                            <span style={{ color: "red" }}> *</span>
                          </Label>
                          <RadioGroup
                            className="mb-10 gap-5 md:gap-36 mt-5"
                            value={registerAsARetailer ? 'true' : 'false'} // Control value with state
                            onValueChange={RegisterAsARetailerConfirm} // Handle value change
                          >
                            <RadioGroupItem value="true" id="transfer">
                              Yes
                            </RadioGroupItem>

                            <RadioGroupItem value="false" id="beneficiary">
                              No
                            </RadioGroupItem>
                          </RadioGroup>

                        </div>
                      </>

                      : null
                  }


                </>
              )}
              {activeStep === 1 && (
                <>
                  <div className="col-span-12 mt-6 mb-4">
                    <h4 className="text-sm font-medium text-default-600">
                      {lang("Enter_Your_Business_Details")}
                    </h4>
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Select Business Type">
                      {" "}
                      {lang("Select_Business_Type")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <select
                      onChange={handleSelectBusinessTypeChange}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                    >
                      <option value="">{lang("Select_Business_Type")}</option>
                      <option value="Kirana and General Store">{lang("Kirana and General Store")}</option>
                      <option value="Medical Shop">{lang("Medical Shop")}</option>
                      <option value="Customer Service Centre">{lang("Customer Service Centre")}</option>
                      <option value="Emitra Centre">{lang("Emitra Centre")}</option>
                      <option value="Traders">{lang("Traders")}</option>
                      <option value="FinTech Company">{lang("FinTech Company")}</option>
                      <option value="Mobile and Telecom">{lang("Mobile and Telecom")}</option>
                      <option value="Electrical and Electronics">{lang("Electrical and Electronics")}</option>
                      <option value="Stationary and Printing">{lang("Stationary and Printing")}</option>
                      <option value="Cloth & Garments Shop">{lang("Cloth & Garments Shop")}</option>
                      <option value="Hotel & Restaurant">{lang("Hotel & Restaurant")}</option>
                      <option value="Others">{lang("Others")}</option>
                    </select>
                  </div>
                  {/* <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Business Name">Business Name<span style={{ color: "red" }}>*</span></Label>
                    <Label htmlFor="Select Business Type">
                      {lang("Select_Business_Type")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>

                    <Select onChange={handleSelectBusinessTypeChange}>
                      <SelectTrigger>
                        <SelectValue
                          placeholder={lang("Select_Business_Type")}
                        />
                      </SelectTrigger>
                      <SelectContent>
                        <SelectItem value="">
                          {lang("Select_Business_Type")}
                        </SelectItem>
                        <SelectItem value="Type 1">Type 1</SelectItem>
                        <SelectItem value="Type 2">Type 2</SelectItem>
                      </SelectContent>
                    </Select>
                  </div> */}
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Business Name">
                      {lang("Business_Name")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={businessName}
                      // onChange={(e) => setBusinessName(e.target.value)}
                      type="text"
                      placeholder={lang("Business_Name")}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[a-zA-Z_ ]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setBusinessName(value); // Update state only if the value is valid
                        }
                      }}
                    />
                    {errors.businessName && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.businessName}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Enter Business Mobile">
                      {lang("Business_Mobile")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={businessMobile}
                      // onChange={(e) => setBusinessMobile(e.target.value)}
                      onChange={handleChangeBusinessMobile}
                      type="tel"
                      maxLength={10}
                      minLength={10}
                      placeholder={lang("Business_Mobile")}
                    />
                    {errors.businessMobile && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.businessMobile}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Enter Business Address">
                      {lang("Business_Address")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={businessAdd}
                      onChange={(e) => setBusinessAdd(e.target.value)}
                      type="text"
                      placeholder={lang("Business_Address")}
                    />
                    {errors.businessAdd && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.businessAdd}
                      </span>
                    )}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Enter State">
                      {lang("State")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    {
                      stateData && stateData.length > 0 ?

                        <Select
                          options={stateData}
                          onChange={(values) => selectStateBusinessName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />

                        :

                        <Select
                          onChange={(values) => selectStateBusinessName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />
                    }

                    {errors.businessState && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.businessState}
                      </span>
                    )}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Enter City">
                      {lang("City")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    {
                      cityBusinessData && cityBusinessData.length > 0 ?

                        <Select
                          options={cityBusinessData}
                          onChange={(values) => selectCityBusinessName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />

                        :

                        <Select
                          onChange={(values) => selectCityBusinessName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />
                    }

                    {errors.businessCity && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.businessCity}
                      </span>
                    )}
                  </div>



                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Pin Code">
                      {lang("Pin_Code")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={businessPincode}
                      onChange={handleChangeBusinessPincode}

                      type="text"
                      placeholder={lang("Pin_Code")}
                      maxLength={6}
                      minLength={6}
                    />
                    {errors.businessPincode && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.businessPincode}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Do you have GST Number">
                      {lang("Do_you_have_GST_Number")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <select
                      onChange={handleSelectChange}
                      className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                    >
                      <option value="">{lang("Do_you_have_GST_Number")}</option>
                      <option value="Yes">{lang("Yes")}</option>
                      <option value="No">{lang("No")}</option>
                    </select>

                    {showGSTInput && (
                      <div style={{ marginTop: "1rem" }}>
                        <Label
                          htmlFor="gstNumberInput"
                          style={{ display: "block", marginBottom: "0.5rem" }}
                        >
                          {lang("GST_Number")}:
                        </Label>
                        <Input
                          id="gstNumberInput"
                          type="text"
                          value={gstNumber.toUpperCase()}
                          onChange={(e) => setGSTNumber(e.target.value.split(" ").join(""))}
                          placeholder={lang("GST_Number")}
                          style={{
                            width: "100%",
                            padding: "0.5rem",
                            fontSize: "1rem",
                            border: "1px solid #ccc",
                            borderRadius: "5px",
                          }}
                        />
                        {errors.gstNumber && (
                          <span
                            style={{
                              color: "tomato",
                              fontWeight: " ",
                              marginBottom: "10px",
                            }}
                            className="error-message"
                          >
                            {errors.gstNumber}
                          </span>
                        )}
                      </div>
                    )}
                  </div>
                </>
              )}
              {activeStep === 2 && (
                <>
                  <div className="col-span-12 mt-6 mb-4">
                    <h4 className="text-sm font-medium text-default-600">
                      {lang("Enter_Your_Bank_Details")}
                    </h4>
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Account Number">
                      {lang("Account_Number")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={accountNumber}
                      // onChange={(e) => setAccountNumber(e.target.value.split(" ").join(""))}
                      type="text"
                      placeholder={lang("Account_Number")}
                      disabled={bankVerify}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[0-9]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setAccountNumber(value); // Update state only if the value is valid
                        }
                      }}
                    />
                    {errors.accountNumber && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.accountNumber}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="IFSC Code">
                      {lang("IFSC_Code")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={ifscCode?.toUpperCase()}
                      onChange={(e) => setIfscCode(e.target.value.split(" ").join(""))}
                      type="text"
                      placeholder={lang("IFSC_Code")}
                      disabled={bankVerify}
                    />
                    {errors.ifscCode && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.ifscCode}
                      </span>
                    )}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Bank Name">
                      {" "}
                      {lang("Bank_Name")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    {
                      bankList && bankList.length > 0 ?

                        <Select
                          options={bankList}
                          onChange={(values) => selectBankName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"


                        />

                        :

                        <Select
                          onChange={(values) => selectBankName(values)}
                          className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-9 text-xs read-only:leading-9"

                        />
                    }
                    {/* <Input
                      value={bankName}
                      onChange={(e) => setBankName(e.target.value)}
                      type="text"
                      placeholder={lang("Bank_Name")}
                    /> */}
                    {errors.bankName && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.bankName}
                      </span>
                    )}
                  </div>
                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Bank Branch Name">
                      {lang("Bank_Branch_Name")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={branchName}
                      onChange={(e) => setBranchName(e.target.value)}
                      type="text"
                      placeholder={lang("Bank_Branch_Name")}
                    />
                    {errors.branchName && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.branchName}
                      </span>
                    )}
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Account Holder Name">
                      {" "}
                      {lang("Account_Holder_Name")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      value={accountHolderName}
                      // onChange={(e) => setAccountHolderName(e.target.value)}
                      type="text"
                      placeholder={lang("Account_Holder_Name")}
                      disabled={bankVerify}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[a-zA-Z_ ]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setAccountHolderName(value); // Update state only if the value is valid
                        }
                      }}
                    />
                    {errors.accountHolderName && (
                      <span
                        style={{
                          color: "tomato",
                          fontWeight: " ",
                          marginBottom: "10px",
                        }}
                        className="error-message"
                      >
                        {errors.accountHolderName}
                      </span>
                    )}
                  </div>



                  <div className="col-span-12 lg:col-span-6">

                    {bankVerify == false ? (

                      <>
                        {
                          verifyBankSkip ?

                            <>

                              <Button
                                size="xs"
                                variant="outline"
                                color="success"
                                type="button"
                                onClick={() => verifyBankAccount()}
                                sx={{ mr: 1 }}
                                className="me-2"
                              >
                                {lang("Bank Details verify")}
                                {bankVerifyLoading ? (
                                  <svg
                                    xmlns="http://www.w3.org/2000/svg"
                                    width="2em"
                                    height="2em"
                                    viewBox="0 0 24 24"
                                  >
                                    <g
                                      fill="none"
                                      stroke="currentColor"
                                      stroke-linecap="round"
                                      stroke-width="2"
                                    >
                                      <path
                                        stroke-dasharray="60"
                                        stroke-dashoffset="60"
                                        stroke-opacity="0.3"
                                        d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                      >
                                        <animate
                                          fill="freeze"
                                          attributeName="stroke-dashoffset"
                                          dur="1.3s"
                                          values="60;0"
                                        />
                                      </path>
                                      <path
                                        stroke-dasharray="15"
                                        stroke-dashoffset="15"
                                        d="M12 3C16.9706 3 21 7.02944 21 12"
                                      >
                                        <animate
                                          fill="freeze"
                                          attributeName="stroke-dashoffset"
                                          dur="0.3s"
                                          values="15;0"
                                        />
                                        <animateTransform
                                          attributeName="transform"
                                          dur="1.5s"
                                          repeatCount="indefinite"
                                          type="rotate"
                                          values="0 12 12;360 12 12"
                                        />
                                      </path>
                                    </g>
                                  </svg>
                                ) : null}
                              </Button>

                              <Button
                                size="xs"
                                variant="outline"
                                color="secondary"
                                className="cursor-pointer mt-5"
                                onClick={() => verifyBankAccountSkip()}
                              >
                                Skip
                              </Button>

                            </>

                            : null
                        }


                      </>


                    ) : null}
                  </div>
                </>
              )}
              {activeStep === 3 && (
                <>
                  <div className="col-span-12 mt-6 mb-4">
                    <h4 className="text-sm font-medium text-default-600">
                      {lang("Enter_Your_KYC_documents")}
                    </h4>
                  </div>

                  <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Aadhar Number">
                      {" "}
                      {lang("Aadhar_Number")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      type="text"
                      maxLength={12}
                      minLength={12}
                      placeholder={lang("Aadhar_Number")}
                      value={aadharNum}
                      // onChange={(e) => setAadharNum(e.target.value.split(" ").join(""))}
                      onChange={(e) => {
                        const value = e.target.value;
                        const regex = /^[0-9]*$/; // Only letters, numbers, and underscores allowed
                        if (regex.test(value)) {
                          setAadharNum(value); // Update state only if the value is valid
                        }
                      }}
                    />
                  </div>
                  {/* <div className="col-span-12 lg:col-span-6">
                    <Label htmlFor="Aadhar Name">
                      {lang("Aadhar_Name")}
                      <span style={{ color: "red" }}>*</span>
                    </Label>
                    <Input
                      type="text"
                      placeholder={lang("Aadhar_Name")}
                      value={aadharName}
                      onChange={(e) => setAadharName(e.target.value)}
                    />
                  </div> */}

                  {/* <div className="col-span-12 lg:col-span-6">
                    <Input type="text" placeholder="Aadhar Name" />
                  </div> */}

                  {!showOTPForm && hideVerifyAadharPanButton == false && aadharCardValidation == false ? (
                    <div className="col-span-12 lg:col-span-6 mt-5">
                      {
                        aadharVerifyDataSkip == false ?
                          <>
                            <Button
                              size="xs"
                              variant="outline"
                              color="success"
                              type="button"
                              onClick={() => handleVerify()}
                              sx={{ mr: 1 }}
                            >
                              {lang("Verify_Aadhar_Number")}{" "}
                              {AadharVerifyLoading ? (
                                <svg
                                  xmlns="http://www.w3.org/2000/svg"
                                  width="2em"
                                  height="2em"
                                  viewBox="0 0 24 24"
                                >
                                  <g
                                    fill="none"
                                    stroke="currentColor"
                                    stroke-linecap="round"
                                    stroke-width="2"
                                  >
                                    <path
                                      stroke-dasharray="60"
                                      stroke-dashoffset="60"
                                      stroke-opacity="0.3"
                                      d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                    >
                                      <animate
                                        fill="freeze"
                                        attributeName="stroke-dashoffset"
                                        dur="1.3s"
                                        values="60;0"
                                      />
                                    </path>
                                    <path
                                      stroke-dasharray="15"
                                      stroke-dashoffset="15"
                                      d="M12 3C16.9706 3 21 7.02944 21 12"
                                    >
                                      <animate
                                        fill="freeze"
                                        attributeName="stroke-dashoffset"
                                        dur="0.3s"
                                        values="15;0"
                                      />
                                      <animateTransform
                                        attributeName="transform"
                                        dur="1.5s"
                                        repeatCount="indefinite"
                                        type="rotate"
                                        values="0 12 12;360 12 12"
                                      />
                                    </path>
                                  </g>
                                </svg>
                              ) : null}
                            </Button>
                            <Button
                              size="xs"
                              variant="outline"
                              color="secondary"
                              className="cursor-pointer ml-2"
                              type="button"
                              onClick={() => verifyAadharNumberSkip()}
                            >
                              Skip
                            </Button>
                          </>
                          : null
                      }

                    </div>
                  ) : null}

                  {/* otp form */}
                  {showOTPForm && aadharCardValidation == false ? (
                    <div className="col-span-12 lg:col-span-12 mx-auto">
                      <div className="w-full md:w-[480px] py-5">
                        <div className="2xl:mt-8 mt-6 2xl:text-3xl text-2xl font-bold text-default-900">
                          {lang("Two_Factor_Verification")}
                        </div>
                        <div className="2xl:text-lg text-base text-default-600 mt-2 leading-6">
                          {lang(
                            "Please_enter_the_OTP_for_verify_your_Aadhar_Number"
                          )}
                        </div>
                        <form className="mt-8">
                          <div className="flex flex-wrap  gap-1 lg:gap-6">
                            {otpFields.map((index) => (
                              <Input
                                key={`otp-code-${index}`}
                                type="text"
                                id={`otp${index}`}
                                name={`otp${index}`}
                                value={otp[index]}
                                onChange={(e) => handleChange(e, index)}
                                onKeyDown={(event) =>
                                  handleKeyDown(index, event)
                                }
                                maxLength={1}
                                className="w-10 h-10 sm:w-[60px] sm:h-16 rounded border-default-300 text-center text-2xl font-medium text-default-900"
                                ref={(ref) => (inputRefs.current[index] = ref)}
                              />
                            ))}
                          </div>
                          <div className="mt-6">
                            <div
                              onClick={!isCounting ? handleResend : undefined}
                              className={`cursor-pointer flex justify-end  p-2 rounded-lg ${isCounting ? 'text-gray-500' : 'text-blue-500'} ${isCounting ? '' : 'hover:text-blue-800'}`}
                            >
                              {isCounting ? `${lang("Resend_in")} ${countdown}s` : lang("Resend_OTP")}
                            </div>
                          </div>
                          <div className="mt-6">
                            <Button
                              type="button"
                              className="w-full"
                              size="lg"
                              onClick={() => AadharOtoVerify()}
                              disabled={!isOtpComplete}
                            >
                              {lang("Verify_Now")}{" "}
                              {AadharOtpVerifyLoading ? (
                                <svg
                                  xmlns="http://www.w3.org/2000/svg"
                                  width="2em"
                                  height="2em"
                                  viewBox="0 0 24 24"
                                >
                                  <g
                                    fill="none"
                                    stroke="currentColor"
                                    stroke-linecap="round"
                                    stroke-width="2"
                                  >
                                    <path
                                      stroke-dasharray="60"
                                      stroke-dashoffset="60"
                                      stroke-opacity="0.3"
                                      d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                    >
                                      <animate
                                        fill="freeze"
                                        attributeName="stroke-dashoffset"
                                        dur="1.3s"
                                        values="60;0"
                                      />
                                    </path>
                                    <path
                                      stroke-dasharray="15"
                                      stroke-dashoffset="15"
                                      d="M12 3C16.9706 3 21 7.02944 21 12"
                                    >
                                      <animate
                                        fill="freeze"
                                        attributeName="stroke-dashoffset"
                                        dur="0.3s"
                                        values="15;0"
                                      />
                                      <animateTransform
                                        attributeName="transform"
                                        dur="1.5s"
                                        repeatCount="indefinite"
                                        type="rotate"
                                        values="0 12 12;360 12 12"
                                      />
                                    </path>
                                  </g>
                                </svg>
                              ) : null}
                            </Button>
                          </div>
                        </form>
                      </div>
                    </div>
                  ) : null}

                  {
                    showManualMessage != '' ?

                      <div class="col-span-12 lg:col-span-12"><p style={{ color: 'red' }}><b>{lang("You_have_exceeded")}</b></p></div>


                      : null
                  }

                  {aadharCardValidation ? (
                    <>
                      {
                        panVerifyDataSkip == false ?

                          <>
                            <div className="col-span-12 mt-6 mb-4">

                              <h4 className="text-sm font-medium text-default-600">
                                {lang("PAN_Card_Verify")}
                              </h4>
                            </div>
                            <div className="col-span-12 lg:col-span-6">
                              <Label htmlFor="PAN Card Number">
                                {lang("pancard_number")}<span style={{ color: "red" }}>*</span>
                                <span style={{ color: "red" }}>*</span>
                              </Label>
                              <Input
                                type="text"
                                placeholder={lang("pancard_number")}
                                value={panNumber.toUpperCase()}
                                onChange={(e) => setPanNumber(e.target.value.split(" ").join(""))}
                                maxLength={10}
                                minLength={10}
                              />
                            </div>
                          </>

                          : null
                      }


                      {
                        online_verify_pan == 'No' && panVerifyDataSkip == false ?

                          <div
                            style={{ textAlign: "right" }}
                            className="col-span-12 lg:col-span-2"
                          >
                            <Button
                              size="xs"
                              variant="outline"
                              color="success"
                              type="button"
                              onClick={() => panNumberVerify()}
                              sx={{ mr: 1 }}
                            >
                              {lang("Verify_PAN_Card")}{" "}
                              {panVerifyLoading ? (
                                <svg
                                  xmlns="http://www.w3.org/2000/svg"
                                  width="2em"
                                  height="2em"
                                  viewBox="0 0 24 24"
                                >
                                  <g
                                    fill="none"
                                    stroke="currentColor"
                                    stroke-linecap="round"
                                    stroke-width="2"
                                  >
                                    <path
                                      stroke-dasharray="60"
                                      stroke-dashoffset="60"
                                      stroke-opacity="0.3"
                                      d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                    >
                                      <animate
                                        fill="freeze"
                                        attributeName="stroke-dashoffset"
                                        dur="1.3s"
                                        values="60;0"
                                      />
                                    </path>
                                    <path
                                      stroke-dasharray="15"
                                      stroke-dashoffset="15"
                                      d="M12 3C16.9706 3 21 7.02944 21 12"
                                    >
                                      <animate
                                        fill="freeze"
                                        attributeName="stroke-dashoffset"
                                        dur="0.3s"
                                        values="15;0"
                                      />
                                      <animateTransform
                                        attributeName="transform"
                                        dur="1.5s"
                                        repeatCount="indefinite"
                                        type="rotate"
                                        values="0 12 12;360 12 12"
                                      />
                                    </path>
                                  </g>
                                </svg>
                              ) : null}
                            </Button>
                            <Button
                              size="xs"
                              variant="outline"
                              color="secondary"
                              className="cursor-pointer ml-2"
                              type="button"
                              onClick={() => verifyPanNumberSkip()}
                            >
                              Skip
                            </Button>
                          </div>

                          : null
                      }

                      <div className="col-span-12 lg:col-span-6">
                        <Label className="mt-2 mb-2">
                          {" "}
                          Photo With Shop
                          {/* {lang("Passport_size_photo")} */}
                        </Label>
                        <FileUploader
                          handleChange={handleSelfImageChange}
                          name="image"
                          types={fileTypes}
                        />
                        {selfImage ? (
                          <>
                            <img
                              src={URL.createObjectURL(selfImage)}
                              width="165px"
                            />
                            {
                              uploadPhotoImageId == 0 ?

                                <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                  <Button
                                    size="xs"
                                    variant="outline"
                                    color="success"
                                    type="button"
                                    className="cursor-pointer mt-5"
                                    onClick={() => {
                                      uploadImage('photo_with_shop');
                                    }}
                                    disabled={loadingImageSubmit && uploadImageType == 'photo_with_shop' ? true : false}
                                  >
                                    Upload
                                    {loadingImageSubmit && uploadImageType == 'photo_with_shop' ? (
                                      <svg
                                        xmlns="http://www.w3.org/2000/svg"
                                        width="2em"
                                        height="2em"
                                        viewBox="0 0 24 24"
                                      >
                                        <g
                                          fill="none"
                                          stroke="currentColor"
                                          stroke-linecap="round"
                                          stroke-width="2"
                                        >
                                          <path
                                            stroke-dasharray="60"
                                            stroke-dashoffset="60"
                                            stroke-opacity="0.3"
                                            d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                          >
                                            <animate
                                              fill="freeze"
                                              attributeName="stroke-dashoffset"
                                              dur="1.3s"
                                              values="60;0"
                                            />
                                          </path>
                                          <path
                                            stroke-dasharray="15"
                                            stroke-dashoffset="15"
                                            d="M12 3C16.9706 3 21 7.02944 21 12"
                                          >
                                            <animate
                                              fill="freeze"
                                              attributeName="stroke-dashoffset"
                                              dur="0.3s"
                                              values="15;0"
                                            />
                                            <animateTransform
                                              attributeName="transform"
                                              dur="1.5s"
                                              repeatCount="indefinite"
                                              type="rotate"
                                              values="0 12 12;360 12 12"
                                            />
                                          </path>
                                        </g>
                                      </svg>
                                    ) : null}
                                  </Button>
                                  <div className="mt-5 ml-5">
                                    {uploadProgress > 0 && uploadImageType == 'photo_with_shop' ? `Upload Progress: ${uploadProgress}%` : ''}
                                  </div>
                                </div>

                                :

                                <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                  <Button
                                    size="xs"
                                    variant="outline"
                                    color="destructive"
                                    type="button"
                                    className="cursor-pointer mt-5"
                                    onClick={() => {
                                      uploadRemoveImage('photo_with_shop');
                                    }}
                                  >
                                    Remove

                                  </Button>

                                </div>
                            }
                          </>
                        ) : (
                          <img src={resultData?.image} width="165px" />
                        )}
                      </div>

                      {
                        policeVerificationDocumentSkip ?

                          <div className="col-span-12 lg:col-span-6">
                            <Label className="mt-2 mb-2">
                              {" "}
                              Police Verification Document
                              {/* {lang("Passport_size_photo")} */}
                            </Label>
                            <div class="flex">
                              <FileUploader
                                handleChange={handlePoliceVerificationDocumentChange}
                                name="image"
                                types={fileTypes}
                              />
                              <Button
                                size="xs"
                                variant="outline"
                                color="secondary"
                                className="cursor-pointer ml-2"
                                type="button"
                                onClick={() => setPoliceVerificationDocumentSkip(false)}
                              >
                                Skip
                              </Button>
                            </div>

                            {policeVerificationDocument ? (
                              <>
                                <img
                                  src={URL.createObjectURL(policeVerificationDocument)}
                                  width="165px"
                                />
                                {
                                  uploadPVImageId == 0 ?

                                    <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                      <Button
                                        size="xs"
                                        variant="outline"
                                        color="success"
                                        type="button"
                                        className="cursor-pointer mt-5"
                                        onClick={() => {
                                          uploadImage('police_verification_image');
                                        }}
                                        disabled={loadingImageSubmit && uploadImageType == 'police_verification_image' ? true : false}
                                      >
                                        Upload
                                        {loadingImageSubmit && uploadImageType == 'police_verification_image' ? (
                                          <svg
                                            xmlns="http://www.w3.org/2000/svg"
                                            width="2em"
                                            height="2em"
                                            viewBox="0 0 24 24"
                                          >
                                            <g
                                              fill="none"
                                              stroke="currentColor"
                                              stroke-linecap="round"
                                              stroke-width="2"
                                            >
                                              <path
                                                stroke-dasharray="60"
                                                stroke-dashoffset="60"
                                                stroke-opacity="0.3"
                                                d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                              >
                                                <animate
                                                  fill="freeze"
                                                  attributeName="stroke-dashoffset"
                                                  dur="1.3s"
                                                  values="60;0"
                                                />
                                              </path>
                                              <path
                                                stroke-dasharray="15"
                                                stroke-dashoffset="15"
                                                d="M12 3C16.9706 3 21 7.02944 21 12"
                                              >
                                                <animate
                                                  fill="freeze"
                                                  attributeName="stroke-dashoffset"
                                                  dur="0.3s"
                                                  values="15;0"
                                                />
                                                <animateTransform
                                                  attributeName="transform"
                                                  dur="1.5s"
                                                  repeatCount="indefinite"
                                                  type="rotate"
                                                  values="0 12 12;360 12 12"
                                                />
                                              </path>
                                            </g>
                                          </svg>
                                        ) : null}
                                      </Button>
                                      <div className="mt-5 ml-5">
                                        {uploadProgress > 0 && uploadImageType == 'police_verification_image' ? `Upload Progress: ${uploadProgress}%` : ''}
                                      </div>
                                    </div>

                                    :

                                    <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                      <Button
                                        size="xs"
                                        variant="outline"
                                        color="destructive"
                                        type="button"
                                        className="cursor-pointer mt-5"
                                        onClick={() => {
                                          uploadRemoveImage('police_verification_image');
                                        }}
                                      >
                                        Remove

                                      </Button>

                                    </div>
                                }
                              </>
                            ) : (
                              <img src={resultData?.police_verification_image} width="165px" />
                            )}

                          </div>

                          : null
                      }

                    </>
                  ) : null}
                  <>
                    {/* file upload */}
                    {showUploadDocumentForm && (
                      <>
                        <div className="col-span-12 lg:col-span-12">
                          <Label className="mt-2 mb-2">
                            {lang("Enter_PAN_Card_Number")}
                            <span style={{ color: "red" }}>*</span>
                          </Label>
                          <Input
                            type="text"
                            placeholder={lang("Enter_PAN_Card_Number")}
                            value={panNumber.toUpperCase()}
                            onChange={(e) => setPanNumber(e.target.value)}
                            maxLength={10}
                            minLength={10}
                          />
                        </div>
                        <div className="col-span-12 lg:col-span-6">
                          <Label className="mt-2 mb-2">
                            {lang("Aadhar_card_front_image")}
                            <span style={{ color: "red" }}>*</span>
                          </Label>
                          <FileUploader
                            handleChange={handleAadharCardFrontImageChange}
                            name="image"
                            types={fileTypes}
                          />
                          {adharCardFrontImage ? (
                            <>
                              <img
                                src={URL.createObjectURL(adharCardFrontImage)}
                                width="165px"
                              />
                              {
                                uploadAFrontImageId == 0 ?

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="success"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadImage('aadhar_front');
                                      }}
                                      disabled={loadingImageSubmit && uploadImageType == 'aadhar_front' ? true : false}
                                    >
                                      Upload
                                      {loadingImageSubmit && uploadImageType == 'aadhar_front' ? (
                                        <svg
                                          xmlns="http://www.w3.org/2000/svg"
                                          width="2em"
                                          height="2em"
                                          viewBox="0 0 24 24"
                                        >
                                          <g
                                            fill="none"
                                            stroke="currentColor"
                                            stroke-linecap="round"
                                            stroke-width="2"
                                          >
                                            <path
                                              stroke-dasharray="60"
                                              stroke-dashoffset="60"
                                              stroke-opacity="0.3"
                                              d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="1.3s"
                                                values="60;0"
                                              />
                                            </path>
                                            <path
                                              stroke-dasharray="15"
                                              stroke-dashoffset="15"
                                              d="M12 3C16.9706 3 21 7.02944 21 12"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="0.3s"
                                                values="15;0"
                                              />
                                              <animateTransform
                                                attributeName="transform"
                                                dur="1.5s"
                                                repeatCount="indefinite"
                                                type="rotate"
                                                values="0 12 12;360 12 12"
                                              />
                                            </path>
                                          </g>
                                        </svg>
                                      ) : null}
                                    </Button>
                                    <div className="mt-5 ml-5">
                                      {uploadProgress > 0 && uploadImageType == 'aadhar_front' ? `Upload Progress: ${uploadProgress}%` : ''}
                                    </div>

                                  </div>

                                  :

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="destructive"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadRemoveImage('aadhar_front');
                                      }}
                                    >
                                      Remove

                                    </Button>

                                  </div>
                              }



                            </>
                          ) : (
                            <img src={resultData?.image} width="165px" />
                          )}

                          {errors.adharCardFrontImage && (
                            <span
                              style={{
                                color: "tomato",
                                fontWeight: " ",
                                marginBottom: "10px",
                              }}
                              className="error-message"
                            >
                              {errors.adharCardFrontImage}
                            </span>
                          )}
                        </div>

                        <div className="col-span-12 lg:col-span-6">
                          <Label className="mt-2 mb-2">
                            {lang("Aadhar_card_back_image")}
                            <span style={{ color: "red" }}>*</span>
                          </Label>
                          <FileUploader
                            handleChange={handleAadharCardBackImageChange}
                            name="image"
                            types={fileTypes}
                          />
                          {adharCardBackImage ? (
                            <>
                              <img
                                src={URL.createObjectURL(adharCardBackImage)}
                                width="165px"
                              />
                              {
                                uploadABackImageId == 0 ?

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="success"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadImage('aadhar_back');
                                      }}
                                      disabled={loadingImageSubmit && uploadImageType == 'aadhar_back' ? true : false}
                                    >
                                      Upload
                                      {loadingImageSubmit && uploadImageType == 'aadhar_back' ? (
                                        <svg
                                          xmlns="http://www.w3.org/2000/svg"
                                          width="2em"
                                          height="2em"
                                          viewBox="0 0 24 24"
                                        >
                                          <g
                                            fill="none"
                                            stroke="currentColor"
                                            stroke-linecap="round"
                                            stroke-width="2"
                                          >
                                            <path
                                              stroke-dasharray="60"
                                              stroke-dashoffset="60"
                                              stroke-opacity="0.3"
                                              d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="1.3s"
                                                values="60;0"
                                              />
                                            </path>
                                            <path
                                              stroke-dasharray="15"
                                              stroke-dashoffset="15"
                                              d="M12 3C16.9706 3 21 7.02944 21 12"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="0.3s"
                                                values="15;0"
                                              />
                                              <animateTransform
                                                attributeName="transform"
                                                dur="1.5s"
                                                repeatCount="indefinite"
                                                type="rotate"
                                                values="0 12 12;360 12 12"
                                              />
                                            </path>
                                          </g>
                                        </svg>
                                      ) : null}
                                    </Button>
                                    <div className="mt-5 ml-5">
                                      {uploadProgress > 0 && uploadImageType == 'aadhar_back' ? `Upload Progress: ${uploadProgress}%` : ''}
                                    </div>
                                  </div>

                                  :

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="destructive"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadRemoveImage('aadhar_back');
                                      }}
                                    >
                                      Remove

                                    </Button>

                                  </div>
                              }
                            </>
                          ) : (
                            <img src={resultData?.image} width="165px" />
                          )}

                          {errors.adharCardBackImage && (
                            <span
                              style={{
                                color: "tomato",
                                fontWeight: " ",
                                marginBottom: "10px",
                              }}
                              className="error-message"
                            >
                              {errors.adharCardBackImage}
                            </span>
                          )}
                        </div>

                        <div className="col-span-12 lg:col-span-6">
                          <Label className="mt-2 mb-2">
                            {lang("PAN_Card_image")}<span style={{ color: "red" }}>*</span>
                          </Label>
                          <FileUploader
                            handleChange={handlePanImageChange}
                            name="image"
                            types={fileTypes}
                          />
                          {panImage ? (
                            <>
                              <img
                                src={URL.createObjectURL(panImage)}
                                width="165px"
                              />
                              {
                                uploadPanImageId == 0 ?

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="success"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadImage('pancard_image');
                                      }}
                                      disabled={loadingImageSubmit && uploadImageType == 'pancard_image' ? true : false}
                                    >
                                      Upload
                                      {loadingImageSubmit && uploadImageType == 'pancard_image' ? (
                                        <svg
                                          xmlns="http://www.w3.org/2000/svg"
                                          width="2em"
                                          height="2em"
                                          viewBox="0 0 24 24"
                                        >
                                          <g
                                            fill="none"
                                            stroke="currentColor"
                                            stroke-linecap="round"
                                            stroke-width="2"
                                          >
                                            <path
                                              stroke-dasharray="60"
                                              stroke-dashoffset="60"
                                              stroke-opacity="0.3"
                                              d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="1.3s"
                                                values="60;0"
                                              />
                                            </path>
                                            <path
                                              stroke-dasharray="15"
                                              stroke-dashoffset="15"
                                              d="M12 3C16.9706 3 21 7.02944 21 12"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="0.3s"
                                                values="15;0"
                                              />
                                              <animateTransform
                                                attributeName="transform"
                                                dur="1.5s"
                                                repeatCount="indefinite"
                                                type="rotate"
                                                values="0 12 12;360 12 12"
                                              />
                                            </path>
                                          </g>
                                        </svg>
                                      ) : null}
                                    </Button>
                                    <div className="mt-5 ml-5">
                                      {uploadProgress > 0 && uploadImageType == 'pancard_image' ? `Upload Progress: ${uploadProgress}%` : ''}
                                    </div>
                                  </div>

                                  :

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="destructive"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadRemoveImage('pancard_image');
                                      }}
                                    >
                                      Remove

                                    </Button>

                                  </div>
                              }
                            </>
                          ) : (
                            <img src={resultData?.image} width="165px" />
                          )}
                          {errors.panImage && (
                            <span
                              style={{
                                color: "tomato",
                                fontWeight: " ",
                                marginBottom: "10px",
                              }}
                              className="error-message"
                            >
                              {errors.panImage}
                            </span>
                          )}
                        </div>

                        <div className="col-span-12 lg:col-span-6">
                          <Label className="mt-2 mb-2">
                            {" "}
                            {/* {lang("Passport_size_photo")} */}
                            Photo With Shop
                            <span style={{ color: "red" }}>*</span>
                          </Label>
                          <FileUploader
                            handleChange={handleSelfImageChange}
                            name="image"
                            types={fileTypes}
                          />
                          {selfImage ? (
                            <>
                              <img
                                src={URL.createObjectURL(selfImage)}
                                width="165px"
                              />
                              {
                                uploadPhotoImageId == 0 ?

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="success"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadImage('photo_with_shop');
                                      }}
                                      disabled={loadingImageSubmit && uploadImageType == 'photo_with_shop' ? true : false}
                                    >
                                      Upload
                                      {loadingImageSubmit && uploadImageType == 'photo_with_shop' ? (
                                        <svg
                                          xmlns="http://www.w3.org/2000/svg"
                                          width="2em"
                                          height="2em"
                                          viewBox="0 0 24 24"
                                        >
                                          <g
                                            fill="none"
                                            stroke="currentColor"
                                            stroke-linecap="round"
                                            stroke-width="2"
                                          >
                                            <path
                                              stroke-dasharray="60"
                                              stroke-dashoffset="60"
                                              stroke-opacity="0.3"
                                              d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="1.3s"
                                                values="60;0"
                                              />
                                            </path>
                                            <path
                                              stroke-dasharray="15"
                                              stroke-dashoffset="15"
                                              d="M12 3C16.9706 3 21 7.02944 21 12"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="0.3s"
                                                values="15;0"
                                              />
                                              <animateTransform
                                                attributeName="transform"
                                                dur="1.5s"
                                                repeatCount="indefinite"
                                                type="rotate"
                                                values="0 12 12;360 12 12"
                                              />
                                            </path>
                                          </g>
                                        </svg>
                                      ) : null}
                                    </Button>
                                    <div className="mt-5 ml-5">
                                      {uploadProgress > 0 && uploadImageType == 'photo_with_shop' ? `Upload Progress: ${uploadProgress}%` : ''}
                                    </div>
                                  </div>

                                  :

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="destructive"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadRemoveImage('photo_with_shop');
                                      }}
                                    >
                                      Remove

                                    </Button>

                                  </div>
                              }
                            </>
                          ) : (
                            <img src={resultData?.image} width="165px" />
                          )}
                          {errors.selfImage && (
                            <span
                              style={{
                                color: "tomato",
                                fontWeight: " ",
                                marginBottom: "10px",
                              }}
                              className="error-message"
                            >
                              {errors.selfImage}
                            </span>
                          )}
                        </div>

                        <div className="col-span-12 lg:col-span-6">
                          <Label className="mt-2 mb-2">
                            Bank Passbook / Bank Statement/ Canceled Cheque
                            <span style={{ color: "red" }}>*</span>
                          </Label>
                          <FileUploader
                            handleChange={handleBankImageChange}
                            name="image"
                            types={fileTypes}
                          />
                          {bankImage ? (
                            <>
                              <img
                                src={URL.createObjectURL(bankImage)}
                                width="165px"
                              />
                              {
                                uploadBankImageId == 0 ?

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="success"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadImage('bank_image');
                                      }}
                                      disabled={loadingImageSubmit && uploadImageType == 'bank_image' ? true : false}
                                    >
                                      Upload
                                      {loadingImageSubmit && uploadImageType == 'bank_image' ? (
                                        <svg
                                          xmlns="http://www.w3.org/2000/svg"
                                          width="2em"
                                          height="2em"
                                          viewBox="0 0 24 24"
                                        >
                                          <g
                                            fill="none"
                                            stroke="currentColor"
                                            stroke-linecap="round"
                                            stroke-width="2"
                                          >
                                            <path
                                              stroke-dasharray="60"
                                              stroke-dashoffset="60"
                                              stroke-opacity="0.3"
                                              d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="1.3s"
                                                values="60;0"
                                              />
                                            </path>
                                            <path
                                              stroke-dasharray="15"
                                              stroke-dashoffset="15"
                                              d="M12 3C16.9706 3 21 7.02944 21 12"
                                            >
                                              <animate
                                                fill="freeze"
                                                attributeName="stroke-dashoffset"
                                                dur="0.3s"
                                                values="15;0"
                                              />
                                              <animateTransform
                                                attributeName="transform"
                                                dur="1.5s"
                                                repeatCount="indefinite"
                                                type="rotate"
                                                values="0 12 12;360 12 12"
                                              />
                                            </path>
                                          </g>
                                        </svg>
                                      ) : null}
                                    </Button>
                                    <div className="mt-5 ml-5">
                                      {uploadProgress > 0 && uploadImageType == 'bank_image' ? `Upload Progress: ${uploadProgress}%` : ''}
                                    </div>
                                  </div>

                                  :

                                  <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                    <Button
                                      size="xs"
                                      variant="outline"
                                      color="destructive"
                                      type="button"
                                      className="cursor-pointer mt-5"
                                      onClick={() => {
                                        uploadRemoveImage('bank_image');
                                      }}
                                    >
                                      Remove

                                    </Button>

                                  </div>
                              }
                            </>
                          ) : (
                            <img src={resultData?.image} width="165px" />
                          )}
                          {errors.bankImage && (
                            <span
                              style={{
                                color: "tomato",
                                fontWeight: " ",
                                marginBottom: "10px",
                              }}
                              className="error-message"
                            >
                              {errors.bankImage}
                            </span>
                          )}
                        </div>
                        {
                          policeVerificationDocumentSkip ?

                            <div className="col-span-12 lg:col-span-6">
                              <Label className="mt-2 mb-2">
                                {" "}
                                Police Verification Document
                                <span style={{ color: "red" }}>*</span>
                                {/* {lang("Passport_size_photo")} */}
                              </Label>
                              <div class="flex">
                                <FileUploader
                                  handleChange={handlePoliceVerificationDocumentChange}
                                  name="image"
                                  types={fileTypes}
                                />
                                <Button
                                  size="xs"
                                  variant="outline"
                                  color="secondary"
                                  className="cursor-pointer ml-2"
                                  type="button"
                                  onClick={() => setPoliceVerificationDocumentSkip(false)}
                                >
                                  Skip
                                </Button>
                              </div>

                              {policeVerificationDocument ? (
                                <>
                                  <img
                                    src={URL.createObjectURL(policeVerificationDocument)}
                                    width="165px"
                                  />
                                  {
                                    uploadPVImageId == 0 ?

                                      <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                        <Button
                                          size="xs"
                                          variant="outline"
                                          color="success"
                                          type="button"
                                          className="cursor-pointer mt-5"
                                          onClick={() => {
                                            uploadImage('police_verification_image');
                                          }}
                                          disabled={loadingImageSubmit && uploadImageType == 'police_verification_image' ? true : false}
                                        >
                                          Upload
                                          {loadingImageSubmit && uploadImageType == 'police_verification_image' ? (
                                            <svg
                                              xmlns="http://www.w3.org/2000/svg"
                                              width="2em"
                                              height="2em"
                                              viewBox="0 0 24 24"
                                            >
                                              <g
                                                fill="none"
                                                stroke="currentColor"
                                                stroke-linecap="round"
                                                stroke-width="2"
                                              >
                                                <path
                                                  stroke-dasharray="60"
                                                  stroke-dashoffset="60"
                                                  stroke-opacity="0.3"
                                                  d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                                                >
                                                  <animate
                                                    fill="freeze"
                                                    attributeName="stroke-dashoffset"
                                                    dur="1.3s"
                                                    values="60;0"
                                                  />
                                                </path>
                                                <path
                                                  stroke-dasharray="15"
                                                  stroke-dashoffset="15"
                                                  d="M12 3C16.9706 3 21 7.02944 21 12"
                                                >
                                                  <animate
                                                    fill="freeze"
                                                    attributeName="stroke-dashoffset"
                                                    dur="0.3s"
                                                    values="15;0"
                                                  />
                                                  <animateTransform
                                                    attributeName="transform"
                                                    dur="1.5s"
                                                    repeatCount="indefinite"
                                                    type="rotate"
                                                    values="0 12 12;360 12 12"
                                                  />
                                                </path>
                                              </g>
                                            </svg>
                                          ) : null}
                                        </Button>
                                        <div className="mt-5 ml-5">
                                          {uploadProgress > 0 && uploadImageType == 'police_verification_image' ? `Upload Progress: ${uploadProgress}%` : ''}
                                        </div>
                                      </div>

                                      :

                                      <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                                        <Button
                                          size="xs"
                                          variant="outline"
                                          color="destructive"
                                          type="button"
                                          className="cursor-pointer mt-5"
                                          onClick={() => {
                                            uploadRemoveImage('police_verification_image');
                                          }}
                                        >
                                          Remove

                                        </Button>

                                      </div>
                                  }
                                </>
                              ) : (
                                <img src={resultData?.police_verification_image} width="165px" />
                              )}

                            </div>

                            : null
                        }
                        <div className="col-span-12 lg:col-span-6">
                          <p style={{ color: 'red' }}>All uploaded images must be less than 2 MB in size.</p>
                        </div>
                      </>
                    )}
                  </>
                  {/* <div
                    style={{ textAlign: "right" }}
                    className="col-span-12 lg:col-span-6"
                  >
                    <Button
                      size="xs"
                      variant="outline"
                      color="success"
                      onClick={verify}
                      sx={{ mr: 1 }}
                    >
                      Verify Pan-Card
                    </Button>
                  </div> */}
                </>
              )}
            </div>
          </form>

          <div className="flex pt-2 ">
            <Button
              size="xs"
              variant="outline"
              color="secondary"
              className={cn("cursor-pointer mt-5", {
                hidden: activeStep === 0,
              })}
              onClick={handleBack}
              sx={{ mr: 1 }}
            >
              {lang("Back")}
            </Button>
            <div className="flex-1	gap-4 " />
            <div className="flex	gap-2 ">
              {activeStep === steps.length - 1 ? (
                aadharCardValidation ? (
                  <Button
                    size="xs"
                    variant="outline"
                    color="success"
                    type="button"
                    className="cursor-pointer mt-5"
                    onClick={() => {
                      handleKycSubmit();
                      // handleNext();
                    }}
                  >
                    {lang("Submit")}
                  </Button>
                ) : showUploadDocumentForm ? (
                  <>

                    <div className="flex text-cemnter aligm-center" style={{ alignItems: 'center' }}>

                      <Button
                        size="xs"
                        variant="outline"
                        color="success"
                        type="button"
                        className="cursor-pointer mt-5"
                        onClick={() => {
                          handleKycSubmit();
                          // handleNext();
                        }}
                        disabled={finalSubmitLoading}
                      >
                        {lang("Submit")}
                        {finalSubmitLoading ? (
                          <svg
                            xmlns="http://www.w3.org/2000/svg"
                            width="2em"
                            height="2em"
                            viewBox="0 0 24 24"
                          >
                            <g
                              fill="none"
                              stroke="currentColor"
                              stroke-linecap="round"
                              stroke-width="2"
                            >
                              <path
                                stroke-dasharray="60"
                                stroke-dashoffset="60"
                                stroke-opacity="0.3"
                                d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                              >
                                <animate
                                  fill="freeze"
                                  attributeName="stroke-dashoffset"
                                  dur="1.3s"
                                  values="60;0"
                                />
                              </path>
                              <path
                                stroke-dasharray="15"
                                stroke-dashoffset="15"
                                d="M12 3C16.9706 3 21 7.02944 21 12"
                              >
                                <animate
                                  fill="freeze"
                                  attributeName="stroke-dashoffset"
                                  dur="0.3s"
                                  values="15;0"
                                />
                                <animateTransform
                                  attributeName="transform"
                                  dur="1.5s"
                                  repeatCount="indefinite"
                                  type="rotate"
                                  values="0 12 12;360 12 12"
                                />
                              </path>
                            </g>
                          </svg>
                        ) : null}
                      </Button>
                      <div className="mt-5 ml-5">
                        {progressKycSubmit > 0 ? `Data Uploading Progress: ${progressKycSubmit}%` : ''}
                      </div>
                    </div>


                  </>
                ) : null
              ) : (
                <>
                  {/* // bankVerifyShowButton == true ? */}

                  <Button
                    size="xs"
                    variant="outline"
                    color="secondary"
                    className="cursor-pointer mt-5"
                    onClick={handleNext}
                  >
                    {lang("Next")}
                  </Button>
                </>

                // :

                // <></>

              )}
            </div>
          </div>
        </React.Fragment>
      )}
    </div>
  );
};

export default BasicWizard;
